@@ -81,7 +81,7 @@ pub use self::error::Error;
 /// Useful includes
 pub mod prelude {
     pub use crate::generate::{FnSelfArg, Generator};
-    pub use crate::parse::{Body, FromAttribute, Parse};
+    pub use crate::parse::{AttributeAccess, Body, FromAttribute, Parse};
     pub use crate::Result;
     pub use proc_macro2::*;
 }
@@ -91,7 +91,7 @@ pub mod prelude {
     extern crate proc_macro;
 
     pub use crate::generate::{FnSelfArg, Generator};
-    pub use crate::parse::{Body, FromAttribute, Parse};
+    pub use crate::parse::{AttributeAccess, Body, FromAttribute, Parse};
     pub use crate::Result;
     pub use proc_macro::*;
 }
